Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
// MaxRetries is the maximum number of retry attempts
MaxRetries int
// InitialDelay is the initial delay before the first retry
InitialDelay time.Duration
// MaxDelay is the maximum delay between retries
MaxDelay time.Duration
// Multiplier is the factor by which the delay increases each retry
Multiplier float64
// Jitter adds randomness to delay to prevent thundering herd
Jitter bool
}
Config holds retry configuration parameters
func DefaultConfig ¶
func DefaultConfig() Config
DefaultConfig returns a default retry configuration
Click to show internal directories.
Click to hide internal directories.